/***********************************************************************************************/
/***     Class: AnalogIn, AnalogIn.cpp                                                       ***/
/***********************************************************************************************/
#include <stdio.h>
#include <rxduino.h> 
#include "PinName.h"
#include "AnalogIn.h"
#include "rxbed_iodefine.h"
#include "Assert.h"

AnalogIn::AnalogIn(PinName pin, const char *name) {
// Create an AnalogIn, connected to the specified pin
// Variables
// pin    AnalogIn pin to connect to
// name    (optional) A string to identify the object
    MblibAssertPin("AnalogIn", p, p14, p19) ;
    p = pin ;
    gr_p = IOport[p].gr_pin ;
    objName = name ;
    analogReference(RAW12BIT) ; // // 3.3v, 12bit
#ifdef DEBUG
    printf("p, gr_pin = %d, %d, %d\n",p, gr_p, PIN_P45) ;
#endif
}

// read
float AnalogIn::read() {
// Read the input voltage, represented as a float in the range [0.0, 1.0]
// Variables
// returns    A floating-point value representing the current input voltage, measured as a percentage
    unsigned short v ;
    float f ;
    
    v = analogRead(gr_p) ;
    f = v ;
    f = f / 0x3ff ; // adjust 12bit to float (0.0 - 1.0) ;

#ifdef DEBUG
    printf("AnalogIn::read = %x\n", v) ;
#endif

return v ;
}
    
// read_u16
unsigned short AnalogIn::read_u16() {
// Read the input voltage, represented as an unsigned short in the range [0x0, 0xFFFF]
// Variables
// returns    16-bit unsigned short representing the current input voltage, normalised to a 16-bit value

    unsigned short v ;
    v = analogRead(gr_p) << 4 ; // adjust 12bit to 16bit
#ifdef DEBUG
    printf("AnalogIn::read_u16 = %x\n", v) ;
#endif

    return v ;
    }

// operator float
AnalogIn::operator float() {
// An operator shorthand for read()
// The float() operator can be used as a shorthand for read() to simplify common code sequences
    float v ; // adjust 12bit to float (0.0 - 1.0) ;
    v = (float) analogRead(gr_p) / 0xfff ;
    // v = v / 0xfff ; 
    return v ;
}
    