/* AnalogOut Class *************
 * Copyright (c) 2012 Takashi Kojo
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
*/

#ifndef ANALOGOUT_H
#define ANALOGOUT_H

#include "stdio.h"
#include "PinName.h"

class AnalogOut {
public: 

AnalogOut(PinName pin, const char *name = NULL) ;
// Create an AnalogOut connected to the specified pin
// Variables
//     pin: p53

// write
void write(float value) ;
// Set the output voltage, specified as a percentage (float)
// Variables
// percent    A floating-point value representing the output voltage, specified as a percentage.  The value should lie between 0.0f (representing 0v / 0%) and 1.0f (representing 3.3v / 100%).  Values outside this range will be saturated to 0.0f or 1.0f.

// write_u16
void write_u16(unsigned short value) ;
// Set the output voltage, represented as an unsigned short in the range [0x0, 0xFFFF]
// Variables
// value    16-bit unsigned short representing the output voltage, normalised to a 16-bit value (0x0000 = 0v, 0xFFFF = 3.3v)

// read
float read() ;
// Return the current output voltage setting, measured as a percentage (float)
// Variables
// returns    A floating-point value representing the current voltage being output on the pin, measured as a percentage.  The returned value will lie between 0.0f (representing 0v / 0%) and 1.0f (representing 3.3v / 100%).
// Note
// This value may not match exactly the value set by a previous write.

// operator=
AnalogOut& operator= (float percent) ;
// An operator shorthand for write()

// operator float()
operator float() ;
// An operator shorthand for read()
private:
    unsigned short v ; // most recent written value
    PinName p ;
    const char *ObjName ;
} ;

#endif