/***********************************************************************************************/
/***     Class: BusInOut, BusInOut.cpp                                                           ***/
/***********************************************************************************************/
#include <rxduino.h>
#include "BusInOut.h"
#include "rxbed_iodefine.h"
    
BusInOut::BusInOut(    
        PinName arg_p0,
        PinName arg_p1,
        PinName arg_p2,        
        PinName arg_p3,
        PinName arg_p4,
        PinName arg_p5,
        PinName arg_p6,
        PinName arg_p7,
        PinName arg_p8,
        PinName arg_p9,
        PinName arg_p10,
        PinName arg_p11,
        PinName arg_p12,        
        PinName arg_p13,
        PinName arg_p14,
        PinName arg_p15,
        const char *name){
    // IOport[pin]: port address * * 8 + bitpos
    
    p[0]  = arg_p0 ; 
    p[1]  = arg_p1 ;
    p[2]  = arg_p2 ;
    p[3]  = arg_p3 ;
    p[4]  = arg_p4 ;
    p[5]  = arg_p5 ;
    p[6]  = arg_p6 ;
    p[7]  = arg_p7 ;
    p[8]  = arg_p8 ;
    p[9]  = arg_p9 ;
    p[10] = arg_p10 ;
    p[11] = arg_p11 ;
    p[12] = arg_p12 ;
    p[13] = arg_p13 ;
    p[14] = arg_p14 ;
    p[15] = arg_p15 ;
    
    for(int i = 0; (i<16) && (p[i] != NC) ; i++) {
        *(unsigned char *)(IOport[p[i]].addr + RXBED_PORT_PDR) &= (~readBit[i]) ; // set the bit to Input
        // for read
        readBit[i]  = 0x1 << (IOport[p[i]].bitpos) ;
        bitPos[i] = IOport[p[i]].bitpos ;
        inAddr[i] = (unsigned char *)(IOport[p[i]].addr + RXBED_PORT_PIDR) ;
        // for write
        setBit[i]  = 0x1 << (IOport[p[i]].bitpos) ;
        resetBit[i] = ~setBit[i] ;
        outAddr[i] = (unsigned char *)(IOport[p[i]].addr + RXBED_PORT_PODR) ;

    }
    ObjName = name ;
} 

//#define DEBUG

void BusInOut::write(int value){
    int i, v ;
#ifdef DEBUG
    printf("BusOut::write = %x\n", value) ;
    printf("BusOut::pin = ") ;
#endif

    if(inout == INPUT)
        BusInOut::output() ;
    
    for(i = 0; (i<16) && (p[i] != NC) ; i++) {
        v = (value >> i) & 0x1 ;     
#ifdef DEBUG
        printf("p[%d] ", v) ;
#endif
        if(v) { *outAddr[i] |= setBit[i] ; }
        else  { *outAddr[i] &= resetBit[i] ; }
    }
    outvalue = value ;
#ifdef DEBUG
    printf("p[%d]=%d, ", i, v) ;
#endif
}

int BusInOut::read (){
    int val = 0 ; 

    if(inout == OUTPUT)
        return(outvalue) ;

#ifdef DEBUG
    printf("BusInOut::pin = ") ;
#endif
    for(int i = 0; (i<16) && (p[i] != NC) ; i++) {
        val |= (*inAddr[i] & readBit[i]) >> (bitPos[i] - i) ;
#ifdef DEBUG
        printf("p[%d] ", p[i]) ;
#endif
    }
#ifdef DEBUG
    printf("BusIn::read = %x\n", val) ;
#endif

    return val ;
} 

void BusInOut::output() {
    for(int i = 0; (i<16) && (p[i] != NC) ; i++) {
        *(unsigned char *)(IOport[p[i]].addr + RXBED_PORT_PDR) |= setBit[i] ; // set the bit to Output
        
    }
    inout = OUTPUT ;
    outvalue = 0 ;
          
}

void BusInOut::input() {

    for(int i = 0; (i<16) && (p[i] != NC) ; i++) {
        *(unsigned char *)(IOport[p[i]].addr + RXBED_PORT_PDR) &= (~readBit[i]) ; // set the bit to Input    
    }
    inout = INPUT ;
}

void BusInOut:: operator= (int value) {
    int v ;

    if(inout == INPUT)
        BusInOut::output() ;

#ifdef DEBUG
    printf("BusOut::write = %x\n", value) ;
#endif


#ifdef DEBUG
    printf("BusOut::pin = ") ;
#endif
    
    for(int i = 0; (i<16) && (p[i] != NC) ; i++) {
        v = (value >> i) & 0x1 ;     
#ifdef DEBUG
        printf("p[%d]=%d, ", i, v) ;
#endif
        if(v) { *outAddr[i] |= setBit[i] ; }
        else      { *outAddr[i] &= resetBit[i] ; }
    }
#ifdef DEBUG
        printf("\n") ;
#endif
    outvalue = value ;
    
} 

BusInOut:: operator int(){
    int val ;
    
    if(inout == OUTPUT) {
        return(outvalue) ;
    }
    
    for(int i = 0; (i<16) && (p[i] != NC) ; i++) {
        val |= (*inAddr[i] & readBit[i]) >> (bitPos[i] - i) ;
#ifdef DEBUG
        printf("p[%d] ", p[i]) ;
#endif
    }
#ifdef DEBUG
    printf("BusInOut::read = %x\n", val) ;
#endif
#undef DEBUG
    return val ;
} 
#undef DEBUG

