/* mbedlib_trace usage ***
SET_TRIGGER_IF(expression, trigger) ; 
RESET_TRIGGER_IF(expression, trigger) ; 
SET_TRIGGER(trigger) ;  
RESET_TRIGGER(trigger) ;  
IF_TRIGGER(triger) PRINTF(format, args) ;
IF_TRIGGER(triger) DBG_HALT while(1) ;
***/

#ifdef DBG_TRACER

#define DBG_TRIG_0 (0x1)
#define DBG_TRIG_1 (0x1 << 1)
#define DBG_TRIG_2 (0x1 << 2)
#define DBG_TRIG_3 (0x1 << 3)
#define DBG_TRIG_4 (0x1 << 4)
#define DBG_TRIG_5 (0x1 << 5)

#define DBG_TRACE_0 1
#define DBG_TRACE_1 2
#define DBG_TRACE_2 3
#define DBG_TRACE_3 4
#define DBG_TRACE_4 5
#define DBG_TRACE_5 6
#define DBG_TRACE_6 7
#define DBG_TRACE_7 8
#define DBG_TRACE_8 9

#ifndef DBG_TRACE_FLAGS // default is Trace ALL
#define DBG_TRACE_FLAGS 0xffff
#endif

#define DBG_BUFFSIZE 1000
#define DBG_EXTEND     20
#ifndef DBG_TRIG_FLAGS 
#define DBG_TRIG_FLAGS \
    unsigned long DBG_TriggerFlags = 0 ; \
    unsigned long DBG_TraceFlags = DBG_TRACE_FLAGS ; \
    unsigned long DBG_TraceBuff[DBG_BUFFSIZE+DBG_EXTEND] ; \
    unsigned long DBG_tcount = 0 ;\
    extern struct DBG_TraceType{\
        char *format ;\
        int     size ;\
    } DBG_TraceTypes[] ;\
    int DBG_TraceHead = 0 ;\
    int DBG_TraceTail = DBG_EXTEND-1 ;\
    int DBG_TraceCycle = 0 ;\
    //int DBG_counter = 0 ;
#else
    extern unsigned long DBG_TriggerFlags :
    extern unsigned long DBG_TriggerFlags :
#endif

#define DBG_TTYPE_BEGIN struct DBG_TraceType DBG_TraceTypes[] = { {"dummy\n", -2 /* This must be "-2" for TRACE_HEAD */ },
#define DBG_TTYPE(format, size) {format, size },
#define DBG_TTYPE_END } ;


#define DBG_DEF_VALUE(value) int value ;
#define DBG_SET_VALUE(value, n) value = n ;
#define DBG_COUNTDOWN(value) value -- ;
#define DBG_COUNTUP(value) value ++ ;

#define DBG_SET_TRIGGER_IF(expression, trigger) if(expression)  DBG_TriggerFlags |= (trigger)  
#define DBG_RESET_TRIGGER_IF(expression, trigger) if(expression) DBG_TriggerFlags &= ~(trigger)  
#define DBG_SET_TRIGGER(trigger) DBG_TriggerFlags |= (trigger)  
#define DBG_RESET_TRIGGER(trigger) DBG_TriggerFlags &= ~(trigger)  

#define DBG_IF_TRIGGER(trigger) if(((trigger) & DBG_TriggerFlags) != 0)
#define DBG_PRINTF(format, ...) printf(format, __VA_ARGS__) 
#define DBG_STATEMENT(statement)  statement 
#define DBG_HALT { DBG_PRINTF("DBG_HALT: Flags= %x\n",DBG_TriggerFlags) ; while(1) delay(100) ; }
 
#define DBG_TRACE_HEAD(type) { int pos = DBG_TraceHead+DBG_TraceTypes[type].size+2 ;\
                            if((DBG_TraceCycle == 0) && (pos >= DBG_BUFFSIZE)) {\
                                DBG_TraceCycle++ ;\
                                /* for(int i=0; i< 100; i++){printf("%x,",DBG_TraceBuff[i]); if(i%10==0)printf("\n") ; }*/\
                                DBG_TraceTail = 0 ;\ 
                            }\
                            if((DBG_TraceCycle > 0) && (DBG_TraceTail <= pos)) {\
                                /* printf("\nbefore: next Head=%d, Tail=%d, ", pos, DBG_TraceTail) ;*/ \
                                DBG_TraceTail += (DBG_TraceTypes[DBG_TraceBuff[DBG_TraceTail%DBG_BUFFSIZE]].size+2) ;\
                                /* printf("after: Tail=%d, ", DBG_TraceTail) ;*/\
                                if(DBG_TraceTail <= pos) {\
                                    DBG_TraceTail += (DBG_TraceTypes[DBG_TraceBuff[DBG_TraceTail%DBG_BUFFSIZE]].size+2) ;\ 
                                    /* printf("yet after: Tail=%d", DBG_TraceTail) ;*/\
                                }\
                                DBG_TraceTail %= DBG_BUFFSIZE ;\
                            }\
                        }
#define DBG_TRACE_PUSH(data) \
    DBG_TraceBuff[(DBG_TraceHead++)%DBG_BUFFSIZE] = data ;  /* printf("data=%d\n", data) ;*/  
#define DBG_TRACE_BEGIN(type) \
    DBG_TRACE_HEAD(type) ; DBG_TRACE_PUSH(type); DBG_TRACE_PUSH(micros()) 
#define DBG_TRACE_END DBG_TraceHead %= DBG_BUFFSIZE

#define DBG_TRACE_PRINT1(pos) \
    printf("pos=%3d, %4d uSec:: ", pos, DBG_TraceBuff[(pos+1)%DBG_BUFFSIZE]-lastt) ; lastt = DBG_TraceBuff[(pos+1)%DBG_BUFFSIZE]; printf(DBG_TraceTypes[DBG_TraceBuff[pos]].format, DBG_TraceBuff[(pos+2)%DBG_BUFFSIZE],DBG_TraceBuff[(pos+3)%DBG_BUFFSIZE],DBG_TraceBuff[(pos+4)%DBG_BUFFSIZE],DBG_TraceBuff[(pos+5)%DBG_BUFFSIZE]) ;

#define DBG_TRACE_DUMP \
    { int pos ; int lastt; int dumpsize ; int size ;\
        printf("\nTRACE_DUMP: before DBG_TraceTail=%d, Head=%d, DBG_TraceCycle=%d\n", DBG_TraceTail, DBG_TraceHead, DBG_TraceCycle) ;\
        /* for(int i=DBG_TraceHead; i< DBG_TraceHead+100; i++){printf("%x,",DBG_TraceBuff[i]); if(i%10==0)printf("\n") ; }*/\
        if(DBG_TraceCycle == 0)  pos = 0 ; \
        else pos = DBG_TraceTail ; \
        lastt = DBG_TraceBuff[(pos+1)%DBG_BUFFSIZE] ; \
        if((pos != 0) && (DBG_TraceTail < DBG_TraceHead)) \
            dumpsize = DBG_TraceHead - DBG_TraceTail ;\
        else dumpsize = (DBG_TraceCycle == 0 ? 0 : (DBG_BUFFSIZE - pos)) + DBG_TraceHead ; \
        for(int i=0; i<dumpsize; i+=size) { \
            if(DBG_TraceBuff[(pos)%DBG_BUFFSIZE]==0) { printf("DATA ERROR\n") ; break ; }\
            DBG_TRACE_PRINT1((pos)%DBG_BUFFSIZE) ; \
            pos += (size = DBG_TraceTypes[DBG_TraceBuff[(pos)%DBG_BUFFSIZE]].size+2) ; \
        } \
        printf("\nTRACE_DUMP: DBG_TraceTail=%d, Head=%d, size=%d\n", DBG_TraceTail, DBG_TraceHead, dumpsize) ;\
        for(int i=DBG_TraceHead-10; i< DBG_TraceHead+100; i++){printf("%x,",DBG_TraceBuff[i]); if(i%10==0)printf("\n") ; }\
        printf("\nEnd TRACE_DUMP\n") ;\
     }
    
#else

#define DBG_TRIG_0
#define DBG_TRIG_1
#define DBG_TRIG_2
#define DBG_TRIG_3
#define DBG_TRIG_4
#define DBG_TRIG_5

#define DBG_TRACE_0
#define DBG_TRACE_1
#define DBG_TRACE_2
#define DBG_TRACE_3
#define DBG_TRACE_4
#define DBG_TRACE_5
#define DBG_TRACE_6
#define DBG_TRACE_7
#define DBG_TRACE_8

#ifndef DBG_TRACE_FLAGS // default is Trace ALL
#define DBG_TRACE_FLAGS
#endif

#define DBG_BUFFSIZE
#define DBG_EXTEND
#ifndef DBG_TRIG_FLAGS 
#define DBG_TRIG_FLAGS 
#endif

#define DBG_TTYPE_BEGIN 
#define DBG_TTYPE(format, size)
#define DBG_TTYPE_END


#define DBG_DEF_VALUE(value)
#define DBG_SET_VALUE(value, n) 
#define DBG_COUNTDOWN(value) 
#define DBG_COUNTUP(value)

#define DBG_SET_TRIGGER_IF(expression, trigger)
#define DBG_RESET_TRIGGER_IF(expression, trigger) 
#define DBG_SET_TRIGGER(trigger)
#define DBG_RESET_TRIGGER(trigger)
#define DBG_IF_TRIGGER(trigger)
#define DBG_PRINTF(format, ...)
#define DBG_STATEMENT(statement)
#define DBG_HALT
#define DBG_TRACE_HEAD(type)
#define DBG_TRACE_PUSH(data)
#define DBG_TRACE_BEGIN(type)
#define DBG_TRACE_END
#define DBG_TRACE_PRINT1(pos)
#define DBG_TRACE_DUMP
#endif