/***********************************************************************************************/
/***     Class: DigitalIn, DigitalIn.cpp                                                     ***/
/***********************************************************************************************/
#include <rxduino.h> 
#include "DigitalIn.h"
#include "rxbed_iodefine.h"

DigitalIn::DigitalIn(PinName pin, const char *name){
    // IOport[pin]: port address * * 8 + bitpos
    p = pin ;
    readBit  = 0x1 << (IOport[pin].bitpos) ; 
    bitPos = IOport[pin].bitpos ;
    ioAddr = (unsigned char *)(IOport[pin].addr + RXBED_PORT_PIDR) ;
    *(unsigned char *)(IOport[pin].addr + RXBED_PORT_PDR) &= (~readBit) ; // set the bit to Input
    DOname = name ;
} 

int DigitalIn::read(){
    return (*ioAddr & readBit) >> bitPos ; 
}

void DigitalIn::mode(PinMode mode){
    switch(mode) {
    case PullUp :
        // *(unsigned char *)(ioAddr + RXBED_PORT_PCR) |= readBit ;
        pinMode(IOport[p].gr_pin, INPUT_PULLUP) ;
        break;
    case PullNone :
        *(unsigned char *)(ioAddr + RXBED_PORT_PCR) &= (~readBit) ;    
            break ;
    case OpenDrain :
        if(bitPos%2 == 0) {
            *(unsigned char *)(ioAddr + RXBED_PORT_ODR0) |= (0x1 << (bitPos * 2)) ;
        } else {
            *(unsigned char *)(ioAddr + RXBED_PORT_ODR1) |= (0x1 << (bitPos * 2)) ;
        }
        break ;
    case HighDrive :
        *(unsigned char *)(ioAddr + RXBED_PORT_DSCR) |= readBit ;    
        break ;
    case NormalDrive :
        *(unsigned char *)(ioAddr + RXBED_PORT_DSCR) &= ~readBit ;    
        break ;
    default : 
        break ;
    }
}

DigitalIn:: operator int() { 
#ifdef    DEBUG
    printf("ioAddr=%x, readBit=%x, bitPos=%d\n", ioAddr, readBit, bitPos);
#endif
    return (*ioAddr & readBit) >> bitPos ; 
}  

