/***********************************************************************************************/
/***     Class: DigitalOut, DigitalOut.cpp                                                   ***/
/***********************************************************************************************/
#include <rxduino.h>
#include "DigitalOut.h"
#include "rxbed_iodefine.h"
    
DigitalOut::DigitalOut(PinName pin, const char *name){
    // IOport[pin]: port address * * 8 + bitpos
        p = pin ;
        setBit  = 0x1 << (IOport[pin].bitpos) ; 
        resetBit = ~setBit ;
        ioAddr = (unsigned char *)(IOport[pin].addr + RXBED_PORT_PODR) ;
        *(unsigned char *)(IOport[pin].addr + RXBED_PORT_PDR) |= setBit ; // set the bit to Output
        DOname = name ;
        p = pin ;
} 

void DigitalOut::write(int value){
        
        outvalue = value ;        
        if(value) { *ioAddr |= setBit ; }
        else      { *ioAddr &= resetBit ; } 
}

int DigitalOut::read(){ 
    return(outvalue) ;
} 

void DigitalOut::mode(PinMode mode){
    switch(mode) {
    case PullUp :
        // *(unsigned char *)(ioAddr + RXBED_PORT_PCR) |= setBit ;
        pinMode(IOport[p].gr_pin, INPUT_PULLUP) ;
        break;
    case PullNone :
        *(unsigned char *)(ioAddr + RXBED_PORT_PCR) &= (~setBit) ;    
            break ;
    case OpenDrain :
        printf("Pin: %d, IO address: %x, BitPos: %d,  ", p, ioAddr, IOport[p].bitpos) ; 
        if(IOport[p].bitpos < 4) {
            *(unsigned char *)(ioAddr + RXBED_PORT_ODR0) |= (0x1 << (IOport[p].bitpos * 2)) ;
            printf("ODR0 - Addr: %x, Bitpos: %x\n",(ioAddr + RXBED_PORT_ODR0),  (0x1 << (IOport[p].bitpos * 2))) ;
        } else {
            *(unsigned char *)(ioAddr + RXBED_PORT_ODR1) |= (0x1 << ((IOport[p].bitpos - 4) * 2)) ;
            printf("ODR1 - Addr: %x, Bitpos: %x\n",(ioAddr + RXBED_PORT_ODR1),  (0x1 << ((IOport[p].bitpos - 4) * 2))) ;
        }
        break ;
    case HighDrive :
        *(unsigned char *)(ioAddr + RXBED_PORT_DSCR) |= setBit ;    
        break ;
    case NormalDrive :
        *(unsigned char *)(ioAddr + RXBED_PORT_DSCR) &= ~setBit ;    
        break ;
    default : 
        break ;
    }
}



DigitalOut&DigitalOut:: operator= (int value) {
        outvalue = value ; 
        if(value) { *ioAddr |= setBit ; }
        else      { *ioAddr &= resetBit ; } 
} 

DigitalOut:: operator int(){ 
    return(outvalue) ;
} 
