#ifndef PWMOUT_H
#define PWMOUT_H

#include "stdio.h"
#include "PinName.h"

class PwmOut {
public:
    PwmOut(PinName  pin, const char *name = NULL) ;
    // Create a PwmOut connected to the specified pin
    // Variables
    // pin    PwmOut pin to connect to
    void write(float value) ;
    // Set the ouput duty-cycle, specified as a percentage (float)
    // Variables
    // value    A floating-point value representing the output duty-cycle, specified as a percentage.  The value should lie between 0.0f (representing on 0%) and 1.0f (representing on 100%).  Values outside this range will be saturated to 0.0f or 1.0f.

    float read() ;
    // Return the current output duty-cycle setting, measured as a percentage (float)
    // Variables
    // returns    A floating-point value representing the current duty-cycle being output on the pin, measured as a percentage.  The returned value will lie between 0.0f (representing on 0%) and 1.0f (representing on 100%).
    // Note
    // This value may not match exactly the value set by a previous write.

    void period(float seconds) ;
    // Set the PWM period, specified in seconds (float), keeping the duty cycle the same.
    // Note
    // The resolution is currently in microseconds; periods smaller than this will be set to zero.

    void period_ms(int ms) ;
    // Set the PWM period, specified in milli-seconds (int), keeping the duty cycle the same.

    void period_us(int us) ;
    // Set the PWM period, specified in micro-seconds (int), keeping the duty cycle the same.

    void pulsewidth(float seconds) ;
    // Set the PWM pulsewidth, specified in seconds (float), keeping the period the same.

    void pulsewidth_ms(int ms) ;
    // Set the PWM pulsewidth, specified in milli-seconds (int), keeping the period the same.

    void pulsewidth_us(int us) ;
    // Set the PWM pulsewidth, specified in micro-seconds (int), keeping the period the same.

    PwmOut& operator= (float value) ;
    // A operator shorthand for write()

    operator float() ;
    // An operator shorthand for read()

    static int countInstance ; 

private:
    unsigned short p ;
    const char *ObjName ;
    float duty ;

    } ;
    
#endif
    