/***********************************************************************************************/
/***     Class: Ticker, Ticker.cpp                                                           ***/
/***********************************************************************************************/

#include "Ticker.h"
#include "Assert.h"
 
#include "TimerInterrupt.h"

#define DEBUG

Ticker::Ticker(){
    if(TTbl_NTimers == 0)
        TTbl_init() ;
    MblibAssert("Ticker", (TTbl_NTimers < TTbl_MAXTIMERS), "Too many Ticker/Timeout instances(%d).", TTbl_NTimers+1) ;

    tickerslot = TTbl_NTimers ++ ;
    TTbl_Timer[tickerslot].interval = -1 ;
    TTbl_Timer[tickerslot].timeout = 0xffffffff ;
    
    // printf("Ticker[%d]\n", tickerslot) ;
}

void Ticker::attach(void (*fptr)(void), float t) {

    struct TTbl_Timer_t  *p =  &TTbl_Timer[tickerslot] ;
    MblibAssertFloatPositive("Ticker.attach", t) ;

    p->fptr = fptr ;
       TTbl_set_f(p, t, TICKER) ;

    #ifdef DEBUG
    printf("Ticker[%d].attach(%x, %f), fp_InitSec:%f, fp_InituSec:%d\n", tickerslot, fptr, t, p->fp_InitSec, p->fp_InituSec) ;
    #endif
}

void Ticker::attach_us(void (*fptr)(void), unsigned int t) {

    struct TTbl_Timer_t  *p =  &TTbl_Timer[tickerslot] ;

    p->fptr = fptr ;
    TTbl_set_us(p, t, TICKER) ;
}

template<typename T> void Ticker::attach(T *tptr, void (T::*mptr)(void), float t) {
    
    MblibAssertFloatPositive("Ticker.attach", t) ;
    struct TTbl_Timer_t  *p =  &TTbl_Timer[tickerslot] ;
    p->fptr = tptr->mptr ;
       TTbl_set_f(p, t, TICKER) ;

}

template<typename T> void Ticker::attach_us(T *tptr, void (T::*mptr)(void), unsigned int t) {
    struct TTbl_Timer_t  *p =  &TTbl_Timer[tickerslot] ;

    p->fptr = tptr->mptr ;
    TTbl_set_us(p, t, TICKER) ;
}

void Ticker::detach() {
    TTbl_Timer[tickerslot].interval = -1 ; // inactivate the slot
       TTbl_Timer[tickerslot].timeout = 0xffffffff ;    
}
#undef DEBUG
