/***********************************************************************************************/
/***     Class: Timeout, Timeout.cpp                                                           ***/
/***********************************************************************************************/

#include "Timeout.h"
#include "Assert.h"

#include "TimerInterrupt.h"

// #define DEBUG

Timeout::Timeout(){
    if(TTbl_NTimers == 0)
        TTbl_init() ;
    MblibAssert("Timeout", (TTbl_NTimers < TTbl_MAXTIMERS), "Too many Ticker/Timeout instances(%d).", TTbl_NTimers+1) ;


    TTbl_Timer[TTbl_NTimers].interval = -1 ;
    TTbl_Timer[TTbl_NTimers].timeout = 0xffffffff ;
    timeoutslot = TTbl_NTimers ++ ;
    #ifdef DEBUG
    printf("Timeout[%d]\n", timeoutslot) ;
    #endif
}
 
void Timeout::attach(void (*fptr)(void), float t) {

    struct TTbl_Timer_t  *p =  &TTbl_Timer[timeoutslot] ;
    MblibAssertFloatPositive("Timeout.attach", t) ;
    MblibAssert("Timeout.attach",(t < (float) 0x7fffffff) , "Too large interval time(%f)\n", t) ;
    p->fptr = fptr ;
       TTbl_set_f(p, t, TIMEOUT) ;

    #ifdef DEBUG
    printf("Timeout[%d].attach(%x, %f), fp_InitSec:%f, fp_InituSec:%d\n", timeoutslot, fptr, t, p->fp_InitSec, p->fp_InituSec) ;
    #endif
}

void Timeout::attach_us(void (*fptr)(void), unsigned int t) {

    struct TTbl_Timer_t  *p =  &TTbl_Timer[timeoutslot] ;
    MblibAssert("Timeout.attach_us",(t < 0x7fffffff) , "Too large interval time(%d)\n", t) ;
    p->fptr = fptr ;
    TTbl_set_us(p, t, TIMEOUT) ;
}

template<typename T> void Timeout::attach(T *tptr, void (T::*mptr)(void), float t) {
    
    MblibAssertFloatPositive("Timeout.attach", t) ;
    MblibAssert("Timeout.attach",(t < (float) 0x7fffffff) , "Too large interval time(%f)\n", t) ;
    
    struct TTbl_Timer_t  *p =  &TTbl_Timer[timeoutslot] ;
    p->fptr = tptr->mptr ;
       TTbl_set_f(p, t, TIMEOUT) ;

}

template<typename T> void Timeout::attach_us(T *tptr, void (T::*mptr)(void), unsigned int t) {
    struct TTbl_Timer_t  *p =  &TTbl_Timer[timeoutslot] ;
    MblibAssert("Timeout.attach_us",(t < 0x7fffffff) , "Too large interval time(%d)\n", t) ;
    p->fptr = tptr->mptr ;
    TTbl_set_us(p, t, TIMEOUT) ;
}

void Timeout::detach() {
    TTbl_Timer[timeoutslot].interval = -1 ; // inactivate the slot    
    TTbl_Timer[timeoutslot].timeout = 0xffffffff ;
}
#undef DEBUG
