#include "rxduino.h"
#include "TimerInterrupt.h"
  
#define DBG_TRACER 
#include "DBG_trace.h" 
  
/* mbedlib_trace usage ***
SET_TRIGGER_IF(expression, trigger) ; 
RESET_TRIGGER_IF(expression, trigger) ; 
IF_TRIGGER(triger) PRINTF(format, args) ;
IF_TRIGGER(triger) DBG_HALT while(1) ;
***/ 
DBG_TRIG_FLAGS ;
#define CLOSE_TO_TIMEOUT     DBG_TRIG_0 
#define TRG_TIMEOUT          DBG_TRIG_1
#define TRG_TIMER_OVERFLOW   DBG_TRIG_2
#define TRG_DELAY            DBG_TRIG_3
#define TRG_NEXT_HALT        DBG_TRIG_4

DBG_TTYPE_BEGIN
    DBG_TTYPE("TTbl_set_us: TTbl_set_us(%x), timeout=%x, now_carry=%x, timeout_carry=%x\n", 4)
    DBG_TTYPE("1st Scan: TTbl_Timer[%d].timeout= %x, nextT=%x, lastTimeout=%x\n", 4)
    DBG_TTYPE("2nd Scan: TTbl_Timer[%d].timeout= %x, nextT=%x, lastTimeout=%x\n",4)
    DBG_TTYPE("No Timeout: NextT=%x, now=%x\n", 2) 
    DBG_TTYPE("Set Timer: Timer=%x, now=%x, DBG_EventCount=%d\n", 3)
    DBG_TTYPE("Timeout: expected=%x, now=%x\n", 2)
    DBG_TTYPE("Delay1: TimerIndex=%d, timer=%x, now=%x\n", 3)
    DBG_TTYPE("Delay2: TimerIndex=%d, timer=%x, now=%x\n", 3)
DBG_TTYPE_END 
 
#define TTBL_SET_US    DBG_TRACE_0
#define FIRST_SCAN     DBG_TRACE_1
#define SECOND_SCAN    DBG_TRACE_2
#define NO_TIMEOUT     DBG_TRACE_3
#define SET_TIMER      DBG_TRACE_4
#define TIMEOUT        DBG_TRACE_5
#define TIMER_DELAY1   DBG_TRACE_6
#define TIMER_DELAY2   DBG_TRACE_7

int DBG_EventCount = 0 ;

struct TTbl_Timer_t TTbl_Timer[TTbl_MAXTIMERS] ;
int TTbl_NTimers = 0 ;
  
#define TIMERMASK 0x7fffffff
#define MAXTICK 0x100
#define ARROWANCE 0x8
 
#define DEBUG
#ifdef DEBUG
#include "mbed.h"
DigitalOut tp3(p3) ;
DigitalOut tp4(p4) ;
#endif
  
static unsigned long lastTimeout = 0 ;
static int nextIndex = -1 ;

// This is invoked every second or at the timeout
void fp_timer() {
    #ifdef DEBUG 
         tp4 = ! tp4 ;
    #endif
    TTbl_Timer[nextIndex].fp_sec -- ;
    // printf("p->fp_sec:%f - 1.0\n", p->fp_sec) ;
    if(TTbl_Timer[nextIndex].fp_sec <= 0) {
        // printf("p->fp_sec:%f <= 0.1\n", p->fp_sec) ; 
        if(TTbl_Timer[nextIndex].fp_uSec != 0) {
            // printf("p->fp_uSec:%d\n", p->fp_uSec) ; 
            TTbl_Timer[nextIndex].timeout = micros() + TTbl_Timer[nextIndex].fp_uSec ;
            TTbl_Timer[nextIndex].fp_uSec = 0 ;
        } else {
            if(TTbl_Timer[nextIndex].type == TICKER) {
                TTbl_Timer[nextIndex].timeout += TTbl_Timer[nextIndex].interval ;
                TTbl_Timer[nextIndex].fp_uSec = TTbl_Timer[nextIndex].fp_InituSec ;
                TTbl_Timer[nextIndex].fp_sec = TTbl_Timer[nextIndex].fp_InitSec ;
            } else {
                TTbl_Timer[nextIndex].interval = -1 ;
            }
            TTbl_Timer[nextIndex].fp_fptr() ;
            // printf("p->fp_uSec:%d, call fptr()\n", p->fp_uSec) ;
        }
    }
}


extern "C" void Excep_TMR1_CMIA1(void) __INTTERUPT_FUNC ;

#define setTimerInt(t)     TMR0.TCCR.BYTE = 0x0 ; TMR1.TCORA = (t) - 1 ; // TMR0.TCCR.BYTE = 0x08 ;

void Excep_TMR1_CMIA1(void) { // TICKER_uSec periodic interrupt
    #ifdef DEBUG
    tp3 = 1 ;
    #endif  

    if(nextIndex >= 0) {
        // set TTbl for the next (TICKER/TIMEOUT)
        if(TTbl_Timer[nextIndex].type == TICKER) {
            // set it for the next
            TTbl_Timer[nextIndex].timeout += TTbl_Timer[nextIndex].interval ;    
        } else { // no next for TIMEOUT
            TTbl_Timer[nextIndex].interval = -1 ;
            TTbl_Timer[nextIndex].timeout = 0xffffffff ;
        }
        // invoke the callback
        TTbl_Timer[nextIndex].fptr() ;
    }
   
    // get next timeout
    unsigned long nextT ;
 
    nextT = 0xffffffff ;  // max unsgned long value
    for(int i=0; i<TTbl_NTimers ; i++) { // scan the ticker table
        if ((TTbl_Timer[i].timeout >= lastTimeout) && (TTbl_Timer[i].timeout < nextT)) {
            nextT = TTbl_Timer[i].timeout ;
            nextIndex = i ;
        }
    }

    int timer = nextT -  (lastTimeout = (micros() & TIMERMASK)) ;
    if(timer > 0xff) {
        nextIndex = -1 ; // no next yet.
        setTimerInt(0x100) ;
    } else {
        if(timer < 2)timer = 2 ;
        setTimerInt(timer) ;
    }
    #ifdef DEBUG
    tp3 = 0 ;
    #endif  
}

static int overflow = 0 ;
void Debug_TimerInt() {
    #ifdef DEBUG
    tp3 = 1 ;
    #endif  

    if(nextIndex >= 0) { 
        // set TTbl for the next (TICKER/TIMEOUT)
        shortcut: // shortcut entry for delayed next timeout
        lastTimeout = TTbl_Timer[nextIndex].timeout ;
        //DBG_TRACE_BEGIN(TIMEOUT); DBG_TRACE_PUSH(TTbl_Timer[nextIndex].timeout) ; DBG_TRACE_PUSH(micros()&TIMERMASK) ; DBG_TRACE_END ;
        if(TTbl_Timer[nextIndex].type == TICKER) {
            // set it for the next
            //TTbl_Timer[nextIndex].now_carry =TTbl_Timer[nextIndex].timeout & (TIMERMASK+1) ;
            TTbl_Timer[nextIndex].timeout += TTbl_Timer[nextIndex].interval ; 
            //TTbl_Timer[nextIndex].timeout_carry = TTbl_Timer[nextIndex].timeout & (TIMERMASK+1) ;
            TTbl_Timer[nextIndex].timeout &= TIMERMASK ;
        } else { // no next for TIMEOUT
            TTbl_Timer[nextIndex].interval = -1 ;
            TTbl_Timer[nextIndex].timeout = 0xffffffff ;
        } 
        // invoke the callback
        TTbl_Timer[nextIndex].fptr() ;
    }  else {
            lastTimeout = micros() ;
            lastTimeout &= TIMERMASK ;
    }
    // get next timeout
    unsigned long nextT ;
    nextIndex = -1 ;
    nextT = 0xffffffff ;  // max unsgned long value
    
    for(int i=0; i<TTbl_NTimers ; i++) { // scan the ticker table
 
        if (TTbl_Timer[i].interval > 0) {
            if(((TTbl_Timer[i].timeout >= lastTimeout) && (TTbl_Timer[i].timeout < (unsigned long)nextT)) ) {
                nextT = TTbl_Timer[i].timeout ;
                nextIndex = i ;
            }
        }
    }
/* 
    if(nextIndex >= 0) {
        //DBG_IF_TRIGGER(CLOSE_TO_TIMEOUT) {
        //    DBG_TRACE_BEGIN(FIRST_SCAN) ; DBG_TRACE_PUSH(nextIndex) ; DBG_TRACE_PUSH(TTbl_Timer[nextIndex].timeout) ; DBG_TRACE_PUSH(nextT) ; DBG_TRACE_PUSH(lastTimeout) ; DBG_TRACE_END ; 
        //}
    //} else { // not found after the lastTimeout. Look for overflowed timers.
        //for(int i=0; i<TTbl_NTimers ; i++) { // scan the ticker table
        //    if (TTbl_Timer[i].interval > 0) {
        //        if(TTbl_Timer[i].timeout < (unsigned long)nextT ) {
        //            nextT = TTbl_Timer[i].timeout ;
        //            nextIndex = i ;
        //        } 
        //    }
        //} 
        //if(nextIndex >= 0) {
            //DBG_IF_TRIGGER(CLOSE_TO_TIMEOUT) {
            //    DBG_TRACE_BEGIN(SECOND_SCAN) ; DBG_TRACE_PUSH(nextIndex) ; DBG_TRACE_PUSH(TTbl_Timer[nextIndex].timeout) ; DBG_TRACE_PUSH(nextT) ; DBG_TRACE_PUSH(lastTimeout) ; DBG_TRACE_END ;
            //} 
        //}   else {
            //DBG_TRACE_BEGIN(NO_TIMEOUT) ; DBG_TRACE_PUSH(nextT) ; DBG_TRACE_PUSH(micros()) ; DBG_TRACE_END ;
        //    DBG_PRINTF("No TIMEOUT\n", nextT) ;
        //    nextIndex = -1 ;
        //    nextT = (micros() + MAXTICK*10) & TIMERMASK ;
        //}  
    //}
    // DBG_IF_TRIGGER(TRG_NEXT_HALT) {DBG_TRACE_DUMP ; DBG_HALT ;}
 */ 
    /*if(DBG_EventCount ++ > 6000) {
        DBG_SET_TRIGGER(TRG_NEXT_HALT) ;
        DBG_PRINTF("NEXT HALT, DBG_EventCount=%d\n", DBG_EventCount) ;
    }*/
   
    int timer ; unsigned long now ;
    // DBG_RESET_TRIGGER(TRG_TIMER_OVERFLOW) ;
  
    // DBG_PRINTF("nextT=%x, DBG_EventCount=%d\n", nextT, DBG_EventCount) ;

    if(nextIndex >= 0) {
        if(nextIndex >= TTbl_NTimers) {
            DBG_PRINTF("ERROR: nextIndex=%d\n", nextIndex) ;
            DBG_HALT ; 
        }
        //now = micros() & ((TIMERMASK<<1) + 1) ;
        //now = now ^ TTbl_Timer[nextIndex].now_carry ;
        now = micros() & TIMERMASK ;
        // nextT = nextT ^ TTbl_Timer[nextIndex].timeout_carry ;
        /*if(nextT <  now) {
            timer = now - nextT ;
            // DBG_TRACE_BEGIN(TIMER_DELAY1) ; DBG_TRACE_PUSH(nextIndex) ; DBG_TRACE_PUSH(timer) ; DBG_TRACE_PUSH(now) ; DBG_TRACE_END ;
            // DBG_SET_TRIGGER(TRG_NEXT_HALT) ;
            // DBG_IF_TRIGGER(TRG_NEXT_HALT) {DBG_TRACE_DUMP ; DBG_HALT ;}
            //goto shortcut ;
        //} else {
        */ 
            timer = nextT - now ;
            if(timer < ARROWANCE) {
                // DBG_TRACE_BEGIN(TIMER_DELAY2) ; DBG_TRACE_PUSH(nextIndex) ; DBG_TRACE_PUSH(timer) ; DBG_TRACE_PUSH(now) ; DBG_TRACE_END ;
                // DBG_IF_TRIGGER(TRG_NEXT_HALT) {DBG_TRACE_DUMP ; DBG_HALT ;}
                goto shortcut ;
            } else { 
                   
            }
        //}   
    } else { 
        timer = MAXTICK ;
        now = micros() & TIMERMASK;
    } 
    // DBG_TRACE_BEGIN(SET_TIMER) ; DBG_TRACE_PUSH(timer) ; DBG_TRACE_PUSH(now) ; DBG_TRACE_PUSH(DBG_EventCount) ; DBG_TRACE_END ;
    // DBG_IF_TRIGGER(TRG_NEXT_HALT) {DBG_TRACE_DUMP ; DBG_HALT ;}
    // DBG_PRINTF("Set Timer: Timer=%x, now=%x, DBG_EventCount=%d\n", timer, now, DBG_EventCount) ;

    #ifdef DEBUG 
    tp3 = 0 ;
    #endif  
    
    //DBG_RESET_TRIGGER(TRG_TIMEOUT) ;
    //DBG_RESET_TRIGGER(CLOSE_TO_TIMEOUT) ;
    //DBG_SET_TRIGGER_IF((timer < MAXTICK*2), CLOSE_TO_TIMEOUT) ;
    if(timer >= MAXTICK) {
        //printf("timer(%x) > 0xff, now=%x\n", timer, now) ;
        nextIndex = -1 ; // no next yet.
        setTimerInt(MAXTICK-ARROWANCE) ;
        delayMicroseconds(MAXTICK-ARROWANCE) ;
    } else {
        //DBG_SET_TRIGGER(TRG_TIMEOUT) ;
        if(timer < 0) {
            //DBG_SET_TRIGGER(TRG_NEXT_HALT) ;
        }
        setTimerInt(timer-ARROWANCE) ;
        delayMicroseconds(timer-ARROWANCE) ;
    }
}

extern   void  InitUSBCom(int) ;
void    TTbl_init() {

    // initialize only once
    if(TTbl_NTimers != 0) return ;
    InitUSBCom(0) ;
     wait(5.0) ;
     

    // Setup Timer interrupt for Ticker/Timeout
    MSTP(TMR0) = 0 ;
    TMR0.TCORA = 48-1 ;              // 48MHz / 48 = 1 uSec
    TMR1.TCORA = MAXTICK -1 ;     // 1uSec * TICKER_uSec

    TMR0.TCR.BIT.CCLR = 0x01 ;
    TMR1.TCR.BIT.CCLR = 0x01 ;

    TMR1.TCCR.BIT.CSS = 3 ;
    TMR1.TCR.BIT.CMIEA = 1 ;
    IEN(TMR1, CMIA1) = 1 ;
    IPR(TMR1, CMIA1) = 1 ;
 
    lastTimeout = micros() ; // referred in Excep_TMR1_CMIA1(void)
    // Start Timer 
    // TMR0.TCCR.BYTE = 0x08 ;
      
}

void TTbl_set_f(struct TTbl_Timer_t *p, float t, TTbl_type type) {
    p->type = type ;
    
    p->fp_InitSec = (int) t ;                    // float fp_sec ;
    p->fp_sec = p->fp_InitSec ;
    p->fp_InituSec = (t - p->fp_sec) * 1000000.0 ;     // int fp_uSec ;
    p->fp_uSec = p->fp_InituSec ;
 
    noInterrupts() ;
    if(p->fp_InitSec > 1) {
        p->interval = 1000000 ; // 1Sec
        p->fp_fptr = p->fptr ;  // save real callback
        p->fptr = fp_timer ;    // set 1 sec timer callback
    } else { // don't use float timer. just set uSec timer
        p->interval = p->fp_InituSec ; 
        p->timeout = micros() + p->interval ;
        p->fp_uSec = -1 ;
    }
    p->timeout = (micros() + p->interval)  & TIMERMASK ;
    interrupts() ;    
}

void TTbl_set_us(struct TTbl_Timer_t *p, unsigned int t, TTbl_type type) {
    unsigned long now ;
    
    p->type = type ;

    // don't use float timer
    p->fp_InitSec = 0 ;    // float fp_sec ;
    p->fp_sec = 0 ;
    p->fp_uSec = -1 ;
    
    // set timer table
    noInterrupts() ;
    p->interval = t ;
    now = micros() ;
    p->now_carry = now & (TIMERMASK+1) ;
    p->timeout = (now &TIMERMASK) + p->interval ;
    p->timeout_carry = p->timeout &(TIMERMASK+1) ;
    p->timeout &= TIMERMASK ;

    interrupts() ;   
    DBG_TRACE_BEGIN(TTBL_SET_US) ; DBG_TRACE_PUSH(t) ; DBG_TRACE_PUSH(p->timeout) ; DBG_TRACE_PUSH(p->now_carry) ; DBG_TRACE_PUSH(p->timeout_carry) ; DBG_TRACE_END ;  
}

void TTbl_reset(struct TTbl_Timer_t *p) {
    noInterrupts() ;
    p->interval = -1 ;
    p->timeout = 0xffffffff ;
    interrupts() ;
}

void TTbl_dump() {
    printf("lastTimeout=%x\n", lastTimeout) ;
    for(int i; i< TTbl_NTimers; i++) {
        printf("%d: %x, %d, %x\n", i, TTbl_Timer[i].fptr,  TTbl_Timer[i].interval,  TTbl_Timer[i].timeout) ;
    }
}

void DBG_next_halt() {
    DBG_PRINTF("NEXT HALT: Ticker ERROR, DBG_EventCount=%d\n", DBG_EventCount) ;
    DBG_SET_TRIGGER(TRG_NEXT_HALT) ;
}
